Configuration

Configuration Provider

ConfigProvider(config_config, *[, ...])

The base configuration provider.

Configuration DataModel

Cohort(*, source[, display_name, splits])

The definition of an expected cohort attribute.

CohortHierarchy(*, name, column_order)

A list of cohort columns representing a hierarchical dependency.

DataUsage(*[, entity_id, context_id, ...])

The definitions of data to use in a notebook run.

DictionaryItem(*, name[, display_name, ...])

Defines a generic dictionary item.

Event(*[, type, group_keys, display_name, ...])

The definition of an event.

EventDictionary(*[, events])

The dictionary information for events data.

EventTableMap(*[, type, time, value])

Override mapping of event table columns.

FilterRange(*[, min, max])

A numeric range filter specifying minimum and/or maximum values.

FilterConfig(*, source[, action, count, ...])

A configurable rule for filtering data based on values in a specific column.

OtherInfo(*[, template, info_dir, ...])

Locations of configuration and data files.

PredictionDictionary(*[, predictions])

The dictionary information for prediction data.